summaryrefslogtreecommitdiffstats
path: root/kftpgrabber/src/misc/plugins/bookmarkimport/filezilla3/kftpimportfz3plugin.h
diff options
context:
space:
mode:
Diffstat (limited to 'kftpgrabber/src/misc/plugins/bookmarkimport/filezilla3/kftpimportfz3plugin.h')
-rw-r--r--kftpgrabber/src/misc/plugins/bookmarkimport/filezilla3/kftpimportfz3plugin.h18
1 files changed, 9 insertions, 9 deletions
diff --git a/kftpgrabber/src/misc/plugins/bookmarkimport/filezilla3/kftpimportfz3plugin.h b/kftpgrabber/src/misc/plugins/bookmarkimport/filezilla3/kftpimportfz3plugin.h
index c340ef5..210430b 100644
--- a/kftpgrabber/src/misc/plugins/bookmarkimport/filezilla3/kftpimportfz3plugin.h
+++ b/kftpgrabber/src/misc/plugins/bookmarkimport/filezilla3/kftpimportfz3plugin.h
@@ -36,7 +36,7 @@
#ifndef KFTPIMPORTFZ3PLUGIN_H
#define KFTPIMPORTFZ3PLUGIN_H
-#include <qdom.h>
+#include <ntqdom.h>
#include <kftpbookmarkimportplugin.h>
/**
@@ -48,22 +48,22 @@ class KFTPImportFz3Plugin : public KFTPBookmarkImportPlugin
{
Q_OBJECT
public:
- KFTPImportFz3Plugin(QObject *parent, const char *name, const QStringList&);
+ KFTPImportFz3Plugin(TQObject *parent, const char *name, const TQStringList&);
/**
* This method should return the properly formated XML for KFTPGrabber
* bookmarks that is generated from the import.
*
* @return The @ref QDomDocument representation of XML
*/
- QDomDocument getImportedXml();
+ TQDomDocument getImportedXml();
/**
* This method should start the import procedure.
*
* @param fileName is the path to the file that will be imported
*/
- void import(const QString &fileName);
+ void import(const TQString &fileName);
/**
* This method should return the default path where the bookmarks could
@@ -71,12 +71,12 @@ public:
*
* @return The default path where bookmarks are located
*/
- QString getDefaultPath();
+ TQString getDefaultPath();
private:
- QDomDocument m_domDocument;
- QDomDocument m_workDocument;
+ TQDomDocument m_domDocument;
+ TQDomDocument m_workDocument;
- void importCategory(QDomNode parent, const QDomNode &node);
+ void importCategory(TQDomNode parent, const TQDomNode &node);
};
#endif
@@ -48,22 +48,22 @@ class KFTPImportFz3Plugin : public KFTPBookmarkImportPlugin
* bookmarks that is generated from the import.
*
- * @return The @ref QDomDocument representation of XML
+ * @return The @ref TQDomDocument representation of XML
*/